Dialog

Struct Dialog 

pub struct Dialog { /* private fields */ }
Dialog represents a browser dialog (alert, confirm, prompt, or beforeunload).

Dialogs are dispatched via the page.on(‘dialog’) event. Dialogs must be explicitly accepted or dismissed, otherwise the page will freeze waiting for the dialog to be handled.

See module-level documentation for usage examples.

See: https://playwright.dev/docs/api/class-dialog

Implementations

Source

impl Dialog

pub fn new( parent: Arc<dyn ChannelOwner>, type_name: String, guid: Arc<str>, initializer: Value, ) -> Result<Self>

Creates a new Dialog from protocol initialization

This is called by the object factory when the server sends a __create__ message for a Dialog object.

pub fn type_(&self) -> &str

Returns the dialog’s type.

Returns one of:

  • “alert” - Simple notification dialog
  • “confirm” - Yes/No confirmation dialog
  • “prompt” - Text input dialog
  • “beforeunload” - Page unload confirmation dialog

See: https://playwright.dev/docs/api/class-dialog#dialog-type

pub fn message(&self) -> &str

Returns the message displayed in the dialog.

See: https://playwright.dev/docs/api/class-dialog#dialog-message

pub fn default_value(&self) -> &str

Returns the default value for prompt dialogs.

For prompt dialogs, returns the default input value. For other dialog types (alert, confirm, beforeunload), returns an empty string.

See: https://playwright.dev/docs/api/class-dialog#dialog-default-value

pub async fn accept(&self, prompt_text: Option<&str>) -> Result<()>

Accepts the dialog.

For prompt dialogs, optionally provides text input. For other dialog types, the promptText parameter is ignored.

Arguments
  • prompt_text - Optional text to enter in a prompt dialog
Errors

Returns error if:

  • Dialog has already been accepted or dismissed
  • Communication with browser process fails

See: https://playwright.dev/docs/api/class-dialog#dialog-accept

pub async fn dismiss(&self) -> Result<()>

Dismisses the dialog.

For confirm dialogs, this is equivalent to clicking “Cancel”. For prompt dialogs, this is equivalent to clicking “Cancel”.

Errors

Returns error if:

  • Dialog has already been accepted or dismissed
  • Communication with browser process fails

See: https://playwright.dev/docs/api/class-dialog#dialog-dismiss