pub struct PipeTransportReceiver<R>{ /* private fields */ }Expand description
Receive-only part of PipeTransport
This struct only contains stdout and the message channel, allowing it to run the receive loop without needing stdin. This solves the deadlock issue by separating send and receive.
Implementations
Sourceimpl<R> PipeTransportReceiver<R>
impl<R> PipeTransportReceiver<R>